@@ -18,6 +18,7 @@ from ._frame import CyphalFrame, TRANSFER_ID_MODULO
 from ._identifier import CANID, generate_filter_configurations
 from ._input_dispatch_table import InputDispatchTable
 from ._tracer import CANTracer, CANCapture
+from .media import DataFrame
 
 
 _logger = logging.getLogger(__name__)
@@ -29,13 +30,13 @@ class CANTransportStatistics(pycyphal.transport.TransportStatistics):
     The following invariants apply::
 
         out_frames >= out_frames_loopback
-        in_frames >= in_frames_uavcan >= in_frames_uavcan_accepted
+        in_frames >= in_frames_cyphal >= in_frames_cyphal_accepted
         out_frames_loopback >= in_frames_loopback
     """
 
     in_frames: int = 0  #: Number of genuine frames received from the bus (loopback not included).
-    in_frames_uavcan: int = 0  #: Subset of the above that happen to be valid Cyphal frames.
-    in_frames_uavcan_accepted: int = 0  #: Subset of the above that are useful for the local application.
+    in_frames_cyphal: int = 0  #: Subset of the above that happen to be valid Cyphal frames.
+    in_frames_cyphal_accepted: int = 0  #: Subset of the above that are useful for the local application.
     in_frames_loopback: int = 0  #: Number of loopback frames received from the media instance (not bus).
     in_frames_errored: int = 0  #: How many frames of any kind could not be successfully processed.
 
@@ -51,7 +52,7 @@ class CANTransportStatistics(pycyphal.transport.TransportStatistics):
         irrelevant ones completely autonomously. The value of 0 indicates that none of the frames passed over
         from the media instance are useful for the application (all ignored).
         """
-        return (self.in_frames_uavcan_accepted / self.in_frames) if self.in_frames > 0 else 1.0
+        return (self.in_frames_cyphal_accepted / self.in_frames) if self.in_frames > 0 else 1.0
 
     @property
     def lost_loopback_frames(self) -> int:
@@ -64,6 +65,16 @@ class CANTransportStatistics(pycyphal.transport.TransportStatistics):
         """
         return self.out_frames_loopback - self.in_frames_loopback
 
+    @property
+    def in_frames_uavcan(self) -> int:
+        warnings.warn("Use in_frames_cyphal", DeprecationWarning)
+        return self.in_frames_cyphal
+
+    @property
+    def in_frames_uavcan_accepted(self) -> int:
+        warnings.warn("Use in_frames_cyphal_accepted", DeprecationWarning)
+        return self.in_frames_cyphal_accepted
+
 
 class CANTransport(pycyphal.transport.Transport):
     """
@@ -243,6 +254,24 @@ class CANTransport(pycyphal.transport.Transport):
         """
         return CANTracer()
 
+    async def spoof_frames(self, frames: typing.Sequence[DataFrame], monotonic_deadline: float) -> None:
+        """
+        Inject arbitrary frames into the transport directly.
+        Frames that could not be delivered to the underlying media driver before the deadline are silently dropped.
+        This method is mostly intended for co-existence with other communication protocols that use the same
+        CAN interface (e.g., DroneCAN).
+        """
+        async with self._media_lock:
+            if self._maybe_media is None:
+                raise pycyphal.transport.ResourceClosedError(f"{self} is closed")
+            await self._maybe_media.send(
+                [Envelope(f, loopback=False) for f in frames],
+                monotonic_deadline=monotonic_deadline,
+            )
+            for frame in frames:
+                capture = CANCapture(Timestamp.now(), frame, own=True)
+                pycyphal.util.broadcast(self._capture_handlers)(capture)
+
     async def spoof(self, transfer: pycyphal.transport.AlienTransfer, monotonic_deadline: float) -> bool:
         """
         Spoofing over the CAN transport is trivial and it does not involve reconfiguration of the media layer.
@@ -374,9 +403,9 @@ class CANTransport(pycyphal.transport.Transport):
 
     def _handle_any_frame(self, timestamp: Timestamp, can_id: CANID, frame: CyphalFrame, loopback: bool) -> None:
         if not loopback:
-            self._frame_stats.in_frames_uavcan += 1
+            self._frame_stats.in_frames_cyphal += 1
             if self._handle_received_frame(timestamp, can_id, frame):
-                self._frame_stats.in_frames_uavcan_accepted += 1
+                self._frame_stats.in_frames_cyphal_accepted += 1
         else:
             self._handle_loopback_frame(timestamp, can_id, frame)
 
